#ifndef {{ name | upper }}_{{ name | upper }}_HPP
#define {{ name | upper }}_{{ name | upper }}_HPP

#include <{{ name }}/export.hpp>

namespace {{ name }} {

{{ name | upper }}_EXPORT void {{ name }}();

}

#endif
